@@ -984,6 +984,11 @@ def map01(df, province, parameter_x, method):
     import pandas as pd
     import webbrowser
 
+    # References:
+    # https://gitee.com/riverscn/china-geojson/blob/master/china.json
+    # https://geojson.io/#map=3/31.73/104.24
+    # https://python-visualization.github.io/folium/modules.html#module-folium.map
+
     df = df
     df1 = df[[province, parameter_x]]
 
@@ -1020,7 +1025,7 @@ def map01(df, province, parameter_x, method):
 
     pdsmap = folium.Map(location=[35, 120], zoom_start=4)
     pdsmap.choropleth(
-        geo_data=open('C:/Users/lx379/Desktop/ssappoc/china.json', encoding='utf-8-sig').read(),
+        geo_data=open('china.json', encoding='utf-8-sig').read(),
         data=dfnew,
         columns=['province', 'value'],
         key_on='feature.properties.name',
@@ -1034,8 +1039,8 @@ def map01(df, province, parameter_x, method):
         highlight=True,
     )
 
-    pdsmap.save('PDS_map.html')
-    url = 'PDS_map.html'
+    pdsmap.save('PDS_Map.html')
+    url = 'PDS_Map.html'
     webbrowser.open(url, new=2)
     # display(pdsmap)
 
@@ -1044,11 +1049,11 @@ def map01(df, province, parameter_x, method):
 
 # [planning ↓]
 
-# Map (based on city + province, values = (sum, ave, var, max, min))
+
+
+
 # heatmap()
-
 # Line plot (x-时间序列: 4.移动平均图 Arima  5.时间序列预测 等种种）
-
 # my.data analytics ppt里的图表
 # 多因子相关性矩阵图/
 # SSAP用户报告里绘制的图
